"use strict";
/*
* This program and the accompanying materials are made available under the terms of the *
* Eclipse Public License v2.0 which accompanies this distribution, and is available at *
* https://www.eclipse.org/legal/epl-v20.html                                      *
*                                                                                 *
* SPDX-License-Identifier: EPL-2.0                                                *
*                                                                                 *
* Copyright Contributors to the Zowe Project.                                     *
*                                                                                 *
*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const PromiseQueue = require("promise-queue");
const Profiles_1 = require("./Profiles");
const profileLink_1 = require("./utils/profileLink");
/**
 * The Zowe Explorer API Register singleton that gets exposed to other VS Code
 * extensions to contribute their implementations.
 * @export
 */
class ZoweExplorerExtender {
    /**
     * Access the singleton instance.
     * @static
     * @returns {ZoweExplorerExtender} the ZoweExplorerExtender singleton instance
     */
    static getInstance() {
        return ZoweExplorerExtender.instance;
    }
    /**
     * This method can be used by other VS Code Extensions to access the primary profile.
     *
     * @param primaryNode represents the Tree item that is being used
     * @return The requested profile
     *
     */
    getProfile(primaryNode) {
        return profileLink_1.getProfile(primaryNode);
    }
    /**
     * This method can be used by other VS Code Extensions to access an alternative
     * profile types that can be employed in conjunction with the primary profile to provide
     * alternative support.
     *
     * @param primaryNode represents the Tree item that is being used
     * @return The requested profile
     */
    getLinkedProfile(primaryNode, type) {
        return profileLink_1.getLinkedProfile(primaryNode, type);
    }
    /**
     * After an extenders registered all its API extensions it
     * might want to request that profiles should get reloaded
     * to make them automatically appears in the Explorer drop-
     * down dialogs.
     */
    reloadProfiles() {
        return __awaiter(this, void 0, void 0, function* () {
            // sequentially reload the internal profiles cache to satisfy all the newly added profile types
            ZoweExplorerExtender.refreshProfilesQueue.add(() => Profiles_1.Profiles.getInstance().refresh());
        });
    }
}
exports.ZoweExplorerExtender = ZoweExplorerExtender;
// Queue of promises to process sequentially when multiple extension register in parallel
ZoweExplorerExtender.refreshProfilesQueue = new PromiseQueue(1, Infinity);
/**
 * This object represents a collection of the APIs that get exposed to other VS Code
 * extensions that want to contribute alternative implementations such as alternative ways
 * of retrieving files and data from z/OS.
 */
ZoweExplorerExtender.instance = new ZoweExplorerExtender();

//# sourceMappingURL=ZoweExplorerExtender.js.map
